@@ -8,8 +8,8 @@ import dpath.util
 from voluptuous import Any
 
 from dvc.exceptions import DvcException
-from dvc.hash_info import HashInfo
 from dvc.utils.serialize import LOADERS, ParseError
+from dvc_objects.hash_info import HashInfo
 
 from .base import Dependency
 
