@@ -8,10 +8,8 @@ from pathspec.patterns import GitWildMatchPattern
 from pathspec.util import normalize_file
 from pygtrie import Trie
 
-from dvc.fs.base import AnyFSPath, FileSystem
-from dvc.fs.local import localfs
+from dvc.fs import AnyFSPath, FileSystem, Schemes, localfs
 from dvc.pathspec_math import PatternInfo, merge_patterns
-from dvc.scheme import Schemes
 from dvc.types import List, Optional
 
 logger = logging.getLogger(__name__)
@@ -35,7 +33,6 @@ class DvcIgnorePatterns(DvcIgnore):
         self.sep = sep
         self.pattern_list = pattern_list
         self.dirname = dirname
-        self.prefix = self.dirname + self.sep
 
         self.regex_pattern_list = [
             GitWildMatchPattern.pattern_to_regex(pattern_info.patterns)
@@ -74,10 +71,13 @@ class DvcIgnorePatterns(DvcIgnore):
     def _get_normalize_path(self, dirname, basename):
         # NOTE: `relpath` is too slow, so we have to assume that both
         # `dirname` and `self.dirname` are relative or absolute together.
+
+        prefix = self.dirname.rstrip(self.sep) + self.sep
+
         if dirname == self.dirname:
             path = basename
-        elif dirname.startswith(self.prefix):
-            rel = dirname[len(self.prefix) :]
+        elif dirname.startswith(prefix):
+            rel = dirname[len(prefix) :]
             # NOTE: `os.path.join` is ~x5.5 slower
             path = f"{rel}{self.sep}{basename}"
         else:
@@ -210,6 +210,7 @@ class DvcIgnoreFilter:
             new_pattern = DvcIgnorePatterns.from_file(path, self.fs, name)
             if old_pattern:
                 plist, prefix = merge_patterns(
+                    self.fs.path.flavour,
                     old_pattern.pattern_list,
                     old_pattern.dirname,
                     new_pattern.pattern_list,
@@ -259,6 +260,7 @@ class DvcIgnoreFilter:
         old_pattern = ignore_trie.longest_prefix(key).value
         if old_pattern:
             plist, prefix = merge_patterns(
+                self.fs.path.flavour,
                 old_pattern.pattern_list,
                 old_pattern.dirname,
                 new_pattern.pattern_list,
@@ -299,7 +301,7 @@ class DvcIgnoreFilter:
 
     def walk(self, fs: FileSystem, path: AnyFSPath, **kwargs):
         ignore_subrepos = kwargs.pop("ignore_subrepos", True)
-        if fs.scheme == Schemes.LOCAL:
+        if fs.protocol == Schemes.LOCAL:
             for root, dirs, files in fs.walk(path, **kwargs):
                 dirs[:], files[:] = self(
                     root, dirs, files, ignore_subrepos=ignore_subrepos
@@ -309,7 +311,7 @@ class DvcIgnoreFilter:
             yield from fs.walk(path, **kwargs)
 
     def find(self, fs: FileSystem, path: AnyFSPath, **kwargs):
-        if fs.scheme == Schemes.LOCAL:
+        if fs.protocol == Schemes.LOCAL:
             for root, _, files in self.walk(fs, path, **kwargs):
                 for file in files:
                     # NOTE: os.path.join is ~5.5 times slower
@@ -402,7 +404,7 @@ class DvcIgnoreFilter:
     ) -> bool:
         # NOTE: can't use self.check_ignore(path).match for now, see
         # https://github.com/iterative/dvc/issues/4555
-        if fs.scheme != Schemes.LOCAL:
+        if fs.protocol != Schemes.LOCAL:
             return False
         if fs.isfile(path):
             return self.is_ignored_file(path, ignore_subrepos)
