@@ -1,11 +1,8 @@
 import inspect
-import os
 from collections.abc import Mapping
 from functools import wraps
 from typing import Callable, Dict, Iterable, List, TypeVar, Union
 
-from pygtrie import StringTrie as _StringTrie
-
 from dvc.exceptions import DvcException
 
 
@@ -17,14 +14,6 @@ class NewParamsFound(DvcException):
         super().__init__("New params found during merge", *args)
 
 
-class PathStringTrie(_StringTrie):
-    """Trie based on platform-dependent separator for pathname components."""
-
-    def __init__(self, *args, **kwargs):
-        kwargs["separator"] = os.sep
-        super().__init__(*args, **kwargs)
-
-
 def apply_diff(src, dest):
     """Recursively apply changes from src to dest.
 
